***This do file shows the Stata code for the multivariate results in
*****"Are risky banks disciplined by large corporate depositors?"
****by
*Björn Imbierowicz, Deutsche Bundesbank, Research Centre, Wilhelm-Epstein-Str.14, 60431 Frankfurt (Germany), Email: bjorn.imbierowicz@gmail.com, Tel: +49 9566 6630.
*Anthony Saunders, New York University, Stern School of Business, Department of Finance, John M. Schiff Professor of Finance, 44 West 4th St., New York, NY 10012 (USA), Email: asaunder@stern.nyu.edu, Tel: +1-212-998-0711.
*Sascha Steffen, Frankfurt School of Finance and Management, Adickesallee 32-34, 60322 Frankfurt (Germany), Email: s.steffen@fs.de, Tel: +49 (0)69 154008-794.

***The data file "Sample of Data 2005-2015.dta" shows the general setup of the data. For reasons of confidentiality, all data has been randomly adjusted.



cd "...path..."
use "Data 2005-2015,clean.dta", clear
cd "...path...\Stataoutput"
replace CDS=CDS/100
replace negquote=0 if quotevalue>=0 & quotevalue!=.
gen timeinterval=1 if effquarter<=189 ///2005:Q1-2007:Q2
replace timeinterval=2 if effquarter>189 & effquarter<=199 ///2007:Q3-2009:Q4 financial crisis
replace timeinterval=3 if effquarter>199 & effquarter<=211 ///2010:Q1-2012:Q4 sovereign debt crisis
replace timeinterval=4 if effquarter>211  ///2013:Q1-2015:Q4

***Financial Crisis, Aug. 9, 2007 - Dec 31, 2009
gen fincrisis=1 if effdate>=17387 & effdate<=18262
replace fincrisis=0 if missing(fincrisis)
***Sovereign Debt Crisis
gen sovdebtcrisis=1 if effyear>=2010 & effyear<=2012
replace sovdebtcrisis=0 if missing(sovdebtcrisis)
***Crisis Aug. 9, 2007 - Dec, 31, 2012
gen crisis=1 if effdate>=17387 & effyear<=2012
replace crisis=0 if missing(crisis)
***pre-post Lehman
gen postLehman=1 if effdate>=17790 & effdate!=.
replace postLehman=0 if missing(postLehman)

***to get all periods in one variable:
gen periods=1 if effdate<17387
replace periods=2 if fincrisis==1
replace periods=3 if sovdebtcrisis==1
replace periods=4 if effyear>2012

***notional
gen helper=notionalamount if exec==1
by auction, sort: egen notional=total(helper)
gen lognotional=ln(notional)
gen logmaturity=ln(duration)

*divide countries into GIIPS, European non-GIIPS, and all others
gen COUNTRY=1 if country=="Austria" | country=="Belgium" | country=="Belgium/Netherlands" | country=="Denmark"| country=="France"| country=="Germany"| country=="Luxembourg"| country=="Netherlands"| country=="Scotland"| country=="Sweden"| country=="UK"
replace COUNTRY=2 if country=="Italien" | country=="Italy" | country=="Ireland" | country=="Spain"
replace COUNTRY=3 if missing(COUNTRY)




*************************************************************************************************************
***Table2
egen bankquarter=group(Provname effquarter)

*T2A.
reghdfe quotevalue  ///
CDS ///
/// firstbid ///
/// logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb( effdate) vce(cluster Provname effmonth)
outreg2 using T2, stats(coef tstat) excel dec(3) cttop(T2A, no other controls)

reghdfe quotevalue  ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb( effdate) vce(cluster Provname effmonth)
outreg2 using T2, stats(coef tstat) excel dec(3) cttop(T2A, main)

reghdfe quotevalue  ///
CDS ///
/// firstbid ///
/// logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb( auction) vce(cluster Provname effmonth)
outreg2 using T2, stats(coef tstat) excel dec(3) cttop(T2A, no other controls)

reghdfe quotevalue  ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb( auction) vce(cluster Provname effmonth)
outreg2 using T2, stats(coef tstat) excel dec(3) cttop(T2A, main)


*T2B.
reghdfe highestbid  ///
CDS ///
/// firstbid ///
/// logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb( effdate) vce(cluster Provname effmonth)
outreg2 using T2, stats(coef tstat) excel dec(3) cttop(T2A, no other controls)

reghdfe highestbid  ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb( effdate) vce(cluster Provname effmonth)
outreg2 using T2, stats(coef tstat) excel dec(3) cttop(T2A, main)

reghdfe highestbid  ///
CDS ///
/// firstbid ///
/// logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb( auction) vce(cluster Provname effmonth)
outreg2 using T2, stats(coef tstat) excel dec(3) cttop(T2A, no other controls)

reghdfe highestbid  ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb( auction) vce(cluster Provname effmonth)
outreg2 using T2, stats(coef tstat) excel dec(3) cttop(T2A, main)








*************************************************************************************************************
***Table3

gen quotevalueperc=quotevalue/100

*T3A.
reghdfe exec ///
quotevalueperc ///
///
/// firstbid ///
/// logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb(auction) vce(cluster Provname effmonth)
outreg2 using T3, stats(coef tstat)  excel dec(3) cttop(T3, quotevalue, total)

reghdfe exec ///
quotevalueperc ///
///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb(auction) vce(cluster Provname effmonth)
outreg2 using T3, stats(coef tstat)  excel dec(3) cttop(T3, quotevalue, total)

reghdfe exec ///
highestbid ///
/// firstbid ///
/// logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb(auction) vce(cluster Provname effmonth)
outreg2 using T3, stats(coef tstat)  excel dec(3) cttop(T3A, highestbid, total)

reghdfe exec ///
highestbid ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb(auction) vce(cluster Provname effmonth)
outreg2 using T3, stats(coef tstat)  excel dec(3) cttop(T3, highestbid, total)


*T3B.
egen Gruppeprice= group(auction quotevalue)

reghdfe exec ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb(Gruppeprice) vce(cluster Provname effmonth)
outreg2 using T3, stats(coef tstat) excel dec(3) cttop(T3, samequote)

gen CDSgroup=1 if CDS<1
replace CDSgroup=2 if CDS>=1 & CDS<2
replace CDSgroup=3 if CDS>=2 & CDS<3
replace CDSgroup=4 if CDS>=3 & CDS!=.

reghdfe exec ///
i.CDSgroup ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb(Gruppeprice) vce(cluster Provname effmonth)
outreg2 using T3, stats(coef tstat) excel dec(3) cttop(T3, samequote)

reghdfe exec ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & highestbid==1, ///
absorb(Gruppeprice) vce(cluster Provname effmonth)
outreg2 using T3, stats(coef tstat) excel dec(3) cttop(T3, samehighestquote)

reghdfe exec ///
i.CDSgroup ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & highestbid==1, ///
absorb(Gruppeprice) vce(cluster Provname effmonth)
outreg2 using T3, stats(coef tstat) excel dec(3) cttop(T3, samehighestquote)

gen Relamount=relamountbanklevel*100
***generate intervals for relationship to get "same" rel
gen Relamountinterval=1 if Relamount<10
replace Relamountinterval=2 if Relamount>=10 & Relamount<20
replace Relamountinterval=3 if Relamount>=20 & Relamount<30
replace Relamountinterval=4 if Relamount>=30 & Relamount<40
replace Relamountinterval=5 if Relamount>=40 & Relamount<50
replace Relamountinterval=6 if Relamount>=50 & Relamount<60
replace Relamountinterval=7 if Relamount>=60 & Relamount<70
replace Relamountinterval=8 if Relamount>=70 & Relamount<80
replace Relamountinterval=9 if Relamount>=80 & Relamount<90
replace Relamountinterval=10 if Relamount>=90 & Relamount!=.

egen Gruppepricerelamount= group(auction quotevalue Relamountinterval)

*T3C.
reghdfe exec ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb(Gruppepricerelamount) vce(cluster Provname effmonth)
outreg2 using T3, stats(coef tstat) excel dec(3) cttop(T3, samequote, sameamtrel)

reghdfe exec ///
i.CDSgroup ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb(Gruppepricerelamount) vce(cluster Provname effmonth)
outreg2 using T3, stats(coef tstat) excel dec(3) cttop(T3, samequote, sameamtrel)

reghdfe exec ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & highestbid==1, ///
absorb(Gruppepricerelamount) vce(cluster Provname effmonth)
outreg2 using T3, stats(coef tstat) excel dec(3) cttop(T3, samehighestquote, sameamtrel)

reghdfe exec ///
i.CDSgroup ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & highestbid==1, ///
absorb(Gruppepricerelamount) vce(cluster Provname effmonth)
outreg2 using T3, stats(coef tstat) excel dec(3) cttop(T3, samehighestquote, sameamtrel)








*************************************************************************************************************
***Table 4


*T4A+C.

***week
cd "...path..."
use "Data 2005-2015,clean.dta", clear
cd "...path...\Stataoutput"

drop if exec!=1
by Requestercompanyid effweek,sort: egen totalamount=total(notionalamount)
collapse totalamount notionalamount CDS reltradesbanklevel relamountbanklevel logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets, by(Requestercompanyid effweek)
tsset Requestercompanyid effweek
sort Requestercompanyid effweek
replace totalamount=totalamount/1000000
replace notionalamount=notionalamount/1000000
***log amounts work exactly the same, not shown for brevity

reghdfe totalamount L.CDS L.logtotassets L.leverage L.npl_grossloans L.ROE L.assetgrowth L.interestmargin L.OBSitems_assets,absorb(Requestercompanyid) vce(cluster effweek)
outreg2 using T4, stats(coef tstat) adjr2 excel dec(3) cttop(TExt5, week, totalamt) replace

reghdfe notionalamount L.CDS L.logtotassets L.leverage L.npl_grossloans L.ROE L.assetgrowth L.interestmargin L.OBSitems_assets,absorb(Requestercompanyid) vce(cluster effweek)
outreg2 using T4, stats(coef tstat) adjr2 excel dec(3) cttop(TExt5, week, notamt)

***month
cd "...path..."
use "Data 2005-2015,clean.dta", clear
cd "...path...\Stataoutput"

drop if exec!=1
by Requestercompanyid effmonth,sort: egen totalamount=total(notionalamount)
collapse totalamount notionalamount CDS reltradesbanklevel relamountbanklevel logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets, by(Requestercompanyid effmonth)
tsset Requestercompanyid effmonth
sort Requestercompanyid effmonth
replace totalamount=totalamount/1000000
replace notionalamount=notionalamount/1000000
***log amounts work exactly the same, not shown for brevity

reghdfe totalamount L.CDS L.logtotassets L.leverage L.npl_grossloans L.ROE L.assetgrowth L.interestmargin L.OBSitems_assets,absorb(Requestercompanyid) vce(cluster  effmonth)
outreg2 using T4, stats(coef tstat) adjr2 excel dec(3) cttop(TExt5, month, totalamt)

reghdfe notionalamount L.CDS L.logtotassets L.leverage L.npl_grossloans L.ROE L.assetgrowth L.interestmargin L.OBSitems_assets,absorb(Requestercompanyid) vce(cluster effmonth)
outreg2 using T4, stats(coef tstat) adjr2 excel dec(3) cttop(TExt5, month, notamt)

***quarter
cd "...path..."
use "Data 2005-2015,clean.dta", clear
cd "...path...\Stataoutput"

drop if exec!=1
by Requestercompanyid effquarter,sort: egen totalamount=total(notionalamount)
collapse totalamount notionalamount CDS reltradesbanklevel relamountbanklevel logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets, by(Requestercompanyid effquarter)
tsset Requestercompanyid effquarter
sort Requestercompanyid effquarter
replace totalamount=totalamount/1000000
replace notionalamount=notionalamount/1000000
***log amounts work exactly the same, not shown for brevity

reghdfe totalamount L.CDS L.logtotassets L.leverage L.npl_grossloans L.ROE L.assetgrowth L.interestmargin L.OBSitems_assets,absorb(Requestercompanyid) vce(cluster effquarter)
outreg2 using T4, stats(coef tstat) adjr2 excel dec(3) cttop(TExt5, quarter, totalamt)

reghdfe notionalamount L.CDS L.logtotassets L.leverage L.npl_grossloans L.ROE L.assetgrowth L.interestmargin L.OBSitems_assets,absorb(Requestercompanyid) vce(cluster effquarter)
outreg2 using T4, stats(coef tstat) adjr2 excel dec(3) cttop(TExt5, quarter, notamt)


*T4B.
***Number banks
*week
cd "...path..."
use "Data 2005-2015,clean.dta", clear
cd "...path...\Stataoutput"
drop Provname
encode provname, gen(Provname)
replace CDS=CDS/100
drop if exec!=1
collapse CDS reltradesbanklevel relamountbanklevel logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets, by(Requestercompanyid Provname effweek)
by Requestercompanyid effweek,sort : gen numberbanks=_N
collapse CDS numberbanks reltradesbanklevel relamountbanklevel logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets, by(Requestercompanyid effweek)
tsset Requestercompanyid effweek
reghdfe numberbanks L.CDS L.logtotassets L.leverage L.npl_grossloans L.ROE L.assetgrowth L.interestmargin L.OBSitems_assets,absorb(Requestercompanyid) vce(cluster effweek)
outreg2 using T4, stats(coef tstat) adjr2 excel dec(3) cttop(TExt5, week, #banks)

*month
cd "...path..."
use "Data 2005-2015,clean.dta", clear
cd "...path...\Stataoutput"
drop Provname
encode provname, gen(Provname)
replace CDS=CDS/100
drop if exec!=1
collapse CDS reltradesbanklevel relamountbanklevel logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets, by(Requestercompanyid Provname effmonth)
by Requestercompanyid effmonth,sort : gen numberbanks=_N
collapse CDS numberbanks reltradesbanklevel relamountbanklevel logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets, by(Requestercompanyid effmonth)
tsset Requestercompanyid effmonth
reghdfe numberbanks L.CDS L.logtotassets L.leverage L.npl_grossloans L.ROE L.assetgrowth L.interestmargin L.OBSitems_assets,absorb(Requestercompanyid) vce(cluster effmonth)
outreg2 using T4, stats(coef tstat) adjr2 excel dec(3) cttop(TExt5, month, #banks)

*quarter
cd "...path..."
use "Data 2005-2015,clean.dta", clear
cd "...path...\Stataoutput"
drop Provname
replace CDS=CDS/100
encode provname, gen(Provname)
drop if exec!=1
collapse CDS reltradesbanklevel relamountbanklevel logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets, by(Requestercompanyid Provname effquarter)
by Requestercompanyid effquarter,sort : gen numberbanks=_N
collapse CDS numberbanks reltradesbanklevel relamountbanklevel logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets, by(Requestercompanyid effquarter)
tsset Requestercompanyid effquarter
reghdfe numberbanks L.CDS L.logtotassets L.leverage L.npl_grossloans L.ROE L.assetgrowth L.interestmargin L.OBSitems_assets,absorb(Requestercompanyid) vce(cluster effquarter)
outreg2 using T4, stats(coef tstat) adjr2 excel dec(3) cttop(TExt5, quarter, #banks)





*************************************************************************************************************
***Table 5

cd "...path..."
use "Data 2005-2015,clean.dta", clear
cd "...path...\Stataoutput"
replace CDS=CDS/100

drop if exec_trans==0
drop if numberquotes==1
gen quotevalueperc=quotevalue/100

by provname effmonth,sort: gen numberbids=_N
by provname effmonth: egen numberwinbids=total(exec)
by provname effmonth: egen numberhighestbids=total(highestbid)
by provname effmonth: egen averrel=mean(relamountbanklevel)
by provname effmonth: egen averquote=mean(quotevalueperc)
by provname effmonth: egen averrisk=mean(CDS)

gen winratio=numberwinbids/numberbids
gen failurerate=1-winratio
gen highestbidratio=numberhighestbids/numberbids

duplicates drop provname effmonth,force

gen loser=1 if failurerate==1
replace loser=0 if failurerate<1 & failurerate!=.

*T5A.
reghdfe failurerate  averquote, absorb(effmonth) vce(cluster Provname) 
outreg2 using T5, stats(coef tstat) excel dec(3) cttop(T5, failure, bank month) replace

reghdfe failurerate  averquote logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets, absorb(Provname effmonth) vce(cluster Provname)
outreg2 using T5, stats(coef tstat) excel dec(3) cttop(T5, failure, bank month)

reghdfe failurerate  highestbidratio , absorb(effmonth) vce(cluster Provname)
outreg2 using T5, stats(coef tstat) excel dec(3) cttop(T5, failure, bank month)

reghdfe failurerate  highestbidratio logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets, absorb(Provname effmonth) vce(cluster Provname)
outreg2 using T5, stats(coef tstat) excel dec(3) cttop(T5, failure, bank month)

*T5B.
reghdfe failurerate  averquote if loser!=1, absorb(effmonth) vce(cluster Provname)
outreg2 using T5, stats(coef tstat) excel dec(3) cttop(T5, failure, bank month) 

reghdfe failurerate  averquote logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets if loser!=1, absorb(Provname effmonth) vce(cluster Provname)
outreg2 using T5, stats(coef tstat) excel dec(3) cttop(T5, failure, bank month)

reghdfe loser  averquote, absorb(effmonth) vce(cluster Provname)
outreg2 using T5, stats(coef tstat) excel dec(3) cttop(T5, failure, bank month)

reghdfe loser  averquote logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets, absorb(Provname effmonth) vce(cluster Provname)
outreg2 using T5, stats(coef tstat) excel dec(3) cttop(T5, failure, bank month)





*************************************************************************************************************
***Table 6

cd "...path..."
use "Data 2005-2015,clean.dta", clear
cd "...path...\Stataoutput"
replace CDS=CDS/100

***notional
gen helper=notionalamount if exec==1
by auction, sort: egen notional=total(helper)
gen lognotional=ln(notional)

egen bankquarter=group(Provname effquarter)


***daily failurerate:
bys Provname effdate: egen winrate_day=mean(exec)
gen failrate_day=1-winrate_day
***weekly failurerate:
bys Provname effweek: egen winrate_week=mean(exec)
gen failrate_week=1-winrate_week
***monthly failurerate:
bys Provname effmonth: egen winrate_month=mean(exec)
gen failrate_month=1-winrate_month
***interest rate average:
bys effmonth: egen avgrate=mean(quotevalue)
***bank interest rate average:
bys Provname effmonth: egen avgbankrate=mean(quotevalue)
***above/below interest rate avrg
gen devrate= avgbankrate-avgrate

bys Provname effmonth exec: egen notional_bank_month=total(notional)
replace notional_bank_month=. if exec!=1
replace notional_bank_month=0 if missing(notional_bank_month)
gen log_notional_bank_month=ln(notional_bank_month+1)
bys Provname effmonth: gen numberbids_bank_month=_N
gen log_numberbids_bank_month=ln(numberbids_bank_month+1)


***for cleaning
reg CDS
outreg2 using T6, stats(coef tstat) adjr2 excel dec(3) cttop(CLEAN) replace

***calculate the average daily change in CDS spread to the failurerate on this day
rangestat (reg) CDS failrate_day , interval (effmonth 0  0) by(Provname)
gen CDSclean_nocontrols = CDS - b_failrate_day 

collapse failrate_month CDS devrate CDSclean_nocontrols b_failrate_day /// 
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
 banktime ///
   notional_bank_month log_notional_bank_month numberbids_bank_month log_numberbids_bank_month ///
, by(Provname effmonth)

tsset Provname effmonth

forvalues i = 1(1)3 {
	qui reghdfe CDSclean_nocontrols L`i'.failrate_month  /// logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
	, noabsorb vce(cluster Provname effmonth)
	outreg2 using T6, stats(coef tstat) adjr2 excel dec(3) cttop(base) addtext(Bank FE, No, Day FE, No) ///
	keep(L`i'.failrate_month  logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets)
}

forvalues i = 1(1)3 {
	qui reghdfe CDSclean_nocontrols L`i'.failrate_month logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
	, absorb(effmonth) vce(cluster Provname effmonth)
	outreg2 using T6, stats(coef tstat) adjr2 excel dec(3) cttop(controls&monthFE) addtext(Bank FE, No, Month FE, Yes) ///
	keep(L`i'.failrate_month  logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets)
}




*************************************************************************************************************
***Table 7

*T7A, columns (1)-(4)

cd "...path..."
use "Data 2005-2015,clean.dta", clear
cd "...path...\Stataoutput"
replace CDS=CDS/100
drop Provname
encode provname, gen(Provname)
drop Requestercompanyid
encode requestercompanyid, gen(Requestercompanyid)

by provname effmonth,sort: gen numberbids=_N
by provname effmonth: egen numberwinbids=total(exec)
by provname effmonth: egen numberhighestbids=total(highestbid)
by provname effmonth: egen averrel=mean(relamountbanklevel)
by provname effmonth: egen averquote=mean(quotevalue)

gen winratio=numberwinbids/numberbids
gen failurerate=1-winratio
gen highestbidratio=numberhighestbids/numberbids
gen highestbidratio2=highestbidratio^2

duplicates drop Provname effmonth,force
tsset Provname effmonth

gen loser=1 if winratio==0
replace loser=0 if winratio>0 & winratio!=.

tsfill
sort Provname effmonth
by Provname: replace provname=provname[_n-1] if missing(provname)

gen noparticipation=1 if numberbids==.
replace noparticipation=0 if numberbids!=.
by Provname: gen reentry=1 if noparticipation[_n-1]==1 & noparticipation==0
replace reentry=0 if noparticipation==1 & missing(reentry)
replace winratio=0 if missing(winratio)

replace effmonth=effmonth-1
drop CDS
merge 1:1 provname effmonth using "...path...\Data\Bank CDS data, monthly.dta" 
drop if _merge==2
drop _merge
replace effmonth=effmonth+1
drop effquarter
gen effquarter=qofd(dofm(effmonth))

***i. A bank is bidding but NO quote is accepted:
sort Provname effmonth
***bank exit
*month FE
reghdfe noparticipation CDS , absorb( effmonth) vce(cluster Provname)
outreg2 using T7, stats(coef tstat) excel dec(3) replace
reghdfe noparticipation L1.CDS , absorb( effmonth) vce(cluster Provname)
outreg2 using T7, stats(coef tstat) excel dec(3) 
*bank and month FE
reghdfe noparticipation CDS , absorb(Provname effmonth) vce(cluster Provname)
outreg2 using T7, stats(coef tstat) excel dec(3) 
reghdfe noparticipation L1.CDS , absorb(Provname effmonth) vce(cluster Provname)
outreg2 using T7, stats(coef tstat) excel dec(3) 


*T7C.
reghdfe reentry CDS , absorb(Provname effmonth) vce(cluster Provname)
outreg2 using T7, stats(coef tstat) excel dec(3) 
reghdfe reentry L1.CDS , absorb(Provname effmonth) vce(cluster Provname)
outreg2 using T7, stats(coef tstat) excel dec(3)
reghdfe reentry L2.CDS , absorb(Provname effmonth) vce(cluster Provname)
outreg2 using T7, stats(coef tstat) excel dec(3) 
reghdfe reentry L3.CDS , absorb(Provname effmonth) vce(cluster Provname)
outreg2 using T7, stats(coef tstat) excel dec(3) 
reghdfe reentry L4.CDS , absorb(Provname effmonth) vce(cluster Provname)
outreg2 using T7, stats(coef tstat) excel dec(3) 


*T7A, columns (5)-(8) & T7B.

***Bank EXIT - between firm and bank
cd "...path..."
use "Data 2005-2015,clean.dta", clear
cd "...path...\Stataoutput"
replace CDS=CDS/100
drop Provname
encode provname, gen(Provname)
drop Requestercompanyid
encode requestercompanyid, gen(Requestercompanyid)

by provname requestercompanyid effmonth,sort: gen numberbids=_N
by provname requestercompanyid effmonth: egen numberwinbids=total(exec)
by provname requestercompanyid effmonth: egen numberhighestbids=total(highestbid)
by provname requestercompanyid effmonth: egen averrel=mean(relamountbanklevel)
by provname requestercompanyid effmonth: egen averquote=mean(quotevalue)

gen winratio=numberwinbids/numberbids
gen failurerate=1-winratio
gen highestbidratio=numberhighestbids/numberbids
gen highestbidratio2=highestbidratio^2

egen firmbank=group(Provname Requestercompanyid)
duplicates drop firmbank effmonth,force
tsset firmbank effmonth

gen loser=1 if winratio==0
replace loser=0 if winratio>0 & winratio!=.

tsfill
sort firmbank effmonth
by firmbank: replace provname=provname[_n-1] if missing(provname)
drop Provname
encode provname, gen(Provname)

gen noparticipation=1 if numberbids==.
replace noparticipation=0 if numberbids!=.
sort firmbank effmonth
by firmbank , sort: gen reentry=1 if L.noparticipation==1 & noparticipation==0
replace reentry=0 if noparticipation==1 & missing(reentry)
replace winratio=0 if missing(winratio)

sort provname effmonth
replace effmonth=effmonth-1
drop CDS
merge m:1 provname effmonth using "...path...\Data\Bank CDS data, monthly.dta" 
drop if _merge==2
drop _merge
replace effmonth=effmonth+1
drop effquarter
gen effquarter=qofd(dofm(effmonth))


*T7A,c.5-8
sort firmbank effmonth
*month FE
reghdfe noparticipation CDS , absorb(effmonth) vce(cluster Provname)
outreg2 using T7, stats(coef tstat) excel dec(3) cttop(T6, exit, monthFE)
reghdfe noparticipation L1.CDS , absorb(effmonth) vce(cluster Provname)
outreg2 using T7, stats(coef tstat) excel dec(3) cttop(T6, exit, monthFE)
*bank-firm and month FE
reghdfe noparticipation CDS , absorb(firmbank effmonth) vce(cluster Provname)
outreg2 using T7, stats(coef tstat) excel dec(3) cttop(T6, exit, bank monthFE)
reghdfe noparticipation L1.CDS , absorb(firmbank effmonth) vce(cluster Provname)
outreg2 using T7, stats(coef tstat) excel dec(3) cttop(T6, exit, bank monthFE)


*T7B.
reghdfe F.CDS noparticipation, absorb(Provname effmonth) vce(cluster Provname)
outreg2 using T7, stats(coef tstat) excel dec(3) cttop(T6, reentry, bank monthFE)
reghdfe F2.CDS noparticipation, absorb(Provname effmonth) vce(cluster Provname)
outreg2 using T7, stats(coef tstat) excel dec(3) cttop(T6, reentry, bank monthFE)
reghdfe F3.CDS noparticipation, absorb(Provname effmonth) vce(cluster Provname)
outreg2 using T7, stats(coef tstat) excel dec(3) cttop(T6, reentry, bank monthFE)
reghdfe F4.CDS noparticipation, absorb(Provname effmonth) vce(cluster Provname)
outreg2 using T7, stats(coef tstat) excel dec(3) cttop(T6, reentry, bank monthFE)



















*************************************************************************************************************
***Table 8

cd "...path..."
use "Data 2005-2015,clean.dta", clear
cd "...path...\Stataoutput"
replace CDS=CDS/100
drop Provname
encode provname, gen(Provname)
drop Requestercompanyid
encode requestercompanyid, gen(Requestercompanyid)

by provname requestercompanyid effmonth,sort: gen numberbids=_N
by provname requestercompanyid effmonth: egen numberwinbids=total(exec)
by provname requestercompanyid effmonth: egen numberhighestbids=total(highestbid)
by provname requestercompanyid effmonth: egen averrel=mean(relamountbanklevel)
by provname requestercompanyid effmonth: egen averquote=mean(quotevalue)

sort effdate
merge m:1 effdate using "...path...\Data\EONIA.dta"
drop if _merge!=3
drop _merge
replace eonia=eonia*100
gen higherthaninterbank=1 if eonia<quotevalue & eonia!=. & quotevalue!=.
replace higherthaninterbank=0 if eonia>=quotevalue & eonia!=. & quotevalue!=.
by provname requestercompanyid effmonth,sort: egen numberhigherthaninterbank=total(higherthaninterbank)
gen higherthaninterbankratio=numberhigherthaninterbank/numberbids 

gen winratio=numberwinbids/numberbids
gen failurerate=1-winratio
gen highestbidratio=numberhighestbids/numberbids
gen highestbidratio2=highestbidratio^2

egen firmbank=group(Provname Requestercompanyid)
duplicates drop firmbank effmonth,force
tsset firmbank effmonth

gen loser=1 if winratio==0
replace loser=0 if winratio>0 & winratio!=.

tsfill
sort firmbank effmonth
by firmbank: replace provname=provname[_n-1] if missing(provname)
drop Provname
encode provname, gen(Provname)

gen noparticipation=1 if numberbids==.
replace noparticipation=0 if numberbids!=.
sort firmbank effmonth
by firmbank , sort: gen reentry=1 if L.noparticipation==1 & noparticipation==0
replace reentry=0 if noparticipation==1 & missing(reentry)
replace winratio=0 if missing(winratio)

sort provname effmonth
replace effmonth=effmonth-1
drop CDS
merge m:1 provname effmonth using "...path...\Data\Bank CDS data, monthly.dta" 
drop if _merge==2
drop _merge
replace effmonth=effmonth+1
drop effquarter
gen effquarter=qofd(dofm(effmonth))

***i. bank exit:
sort firmbank effmonth
reg noparticipation 
outreg2 using T8, cttop(JUSTTOEMPTY) replace


reghdfe noparticipation L.failurerate , absorb(firmbank effmonth) vce(cluster Provname)
outreg2 using T8, stats(coef tstat) excel dec(3) cttop(T7, exit, bankfirm monthFE)
reghdfe noparticipation L.higherthaninterbankratio  , absorb(firmbank effmonth) vce(cluster Provname)
outreg2 using T8, stats(coef tstat) excel dec(3) cttop(T7, exit, bankfirm monthFE)

reghdfe noparticipation  L.higherthaninterbankratio L.failurerate , absorb(effmonth) vce(cluster Provname)
outreg2 using T8, stats(coef tstat) excel dec(3) cttop(T7, exit, monthFE)
reghdfe noparticipation  L.higherthaninterbankratio L.failurerate , absorb(Provname effmonth) vce(cluster Provname)
outreg2 using T8, stats(coef tstat) excel dec(3) cttop(T7, exit, bank monthFE)
reghdfe noparticipation  L.higherthaninterbankratio L.failurerate , absorb(firmbank effmonth) vce(cluster Provname)
outreg2 using T8, stats(coef tstat) excel dec(3) cttop(T7, exit, bankfirm monthFE)










*************************************************************************************************************
***Table 9

/* save separate data file, as Table was created much later in the process, to avoid any confusion 
cd "...path..."
use "Data 2005-2015,clean.dta", clear
cd "...path...\Stataoutput"
replace CDS=CDS/100

***notional
gen helper=notionalamount if exec==1
by auction, sort: egen notional=total(helper)
gen lognotional=ln(notional)
gen logmaturity=ln(duration)

*divide countries into GIIPS, European non-GIIPS, and all others
gen COUNTRY=1 if country=="Austria" | country=="Belgium" | country=="Belgium/Netherlands" | country=="Denmark"| country=="France"| country=="Germany"| country=="Luxembourg"| country=="Netherlands"| country=="Scotland"| country=="Sweden"| country=="UK"
replace COUNTRY=2 if country=="Italien" | country=="Italy" | country=="Ireland" | country=="Spain"
replace COUNTRY=3 if missing(COUNTRY)

egen bankquarter=group(Provname effquarter)

sort Provname requestercompanyid effdate tradetime
by Provname requestercompanyid effdate: gen numtrades=_n
gen notsuccessful=1-exec

by Provname requestercompanyid effdate: gen prevtradenotsuccess=notsuccessful[_n-1]
by Provname requestercompanyid effdate: gen diffquotevalue=quotevalue - quotevalue[_n-1] //this drops the first obs. on a bank-firm-day

egen bankfirmday=group(Provname requestercompanyid effdate)
egen bankday=group(Provname effdate)

save "...path...\data2.dta", relace
*/


*T9A.
use "...path...\data2.dta", clear

sum prevtradenotsuccess diffquotevalue, det

***to clean the Excel file again:
reg CDS
outreg2 using T9, stats(coef tstat) adjr2 excel dec(3) cttop(just to empty) replace

***Regressions
reghdfe diffquotevalue prevtradenotsuccess, absorb( effdate) vce(cluster Provname effmonth)
outreg2 using T9, stats(coef tstat)  excel dec(3) addtext(Day FE, Yes, Bank-Firm FE, No, Bank-Day FE, No, Bank-Firm-Day FE, No)

reghdfe diffquotevalue  prevtradenotsuccess, absorb( bankfirm) vce(cluster Provname effmonth)
outreg2 using T9, stats(coef tstat)  excel dec(3) addtext(Day FE, No, Bank-Firm FE, Yes, Bank-Day FE, No, Bank-Firm-Day FE, No)

reghdfe diffquotevalue  prevtradenotsuccess, absorb( bankfirm effdate) vce(cluster Provname effmonth)
outreg2 using T9, stats(coef tstat)  excel dec(3) addtext(Day FE, Yes, Bank-Firm FE, Yes, Bank-Day FE, No, Bank-Firm-Day FE, No)

reghdfe diffquotevalue  prevtradenotsuccess, absorb( bankfirm bankday) vce(cluster Provname effmonth)
outreg2 using T9, stats(coef tstat)  excel dec(3) addtext(Day FE, Yes, Bank-Firm FE, Yes, Bank-Day FE, Yes, Bank-Firm-Day FE, No)

reghdfe diffquotevalue  prevtradenotsuccess, absorb( bankfirmday) vce(cluster Provname effmonth) //this includes only bank-firm-days with >=3 encounters
outreg2 using T9, stats(coef tstat)  excel dec(3) addtext(Day FE, Yes, Bank-Firm FE, Yes, Bank-Day FE, Yes, Bank-Firm-Day FE, Yes)


*T9B.

cd "...path..."
use "Data 2005-2015,clean.dta", clear
cd "...path...\Stataoutput"
drop Provname
encode provname, gen(Provname)

sort Provname effdate tradetime
by Provname effdate: gen numbidsroll=_n
by Provname effdate: gen numtransroll=sum(exec)

gen dailybanksuccessrate=numtransroll/numbidsroll
gen dailybanklossrate=1-dailybanksuccessrate
by Provname effdate: gen lagdailybanksuccessrate=dailybanksuccessrate[_n-1]
by Provname effdate: gen lagdailybanklossrate=1-lagdailybanksuccessrate

replace CDS=CDS/100
gen hour=hhC( tradetime)
gen tagesverlauf=1 if hour<11
replace tagesverlauf=2 if hour>=11 & hour<=13
replace tagesverlauf=3 if hour>13

*early morning:
gen prior9am=1 if hour<9
replace prior9am=0 if missing(prior9am)
***9 to 11:59:59 is the base effect then!!!
gen base=1 if hour>=9 & hour<=11
replace base=0 if missing(base)
*lunch time
gen between12and13=1 if hour>11 & hour<=13
replace between12and13=0 if missing(between12and13)
*afternoon
gen after13=1 if hour>13
replace after13=0 if missing(after13)

egen bankday=group(Provname effdate)


***do banks bid differently depending on their success on a day?
*banks bid more aggressively when their loss rate increases
reghdfe quotevalue lagdailybanklossrate , absorb(bankday) vce(cluster Provname effmonth)
outreg2 using T9, stats(coef tstat)  excel dec(3) addtext(Day FE, No, Bank-Day FE, Yes)

***what happens to interest rates over the day (base effect is 9am - 11:59:59am):
reghdfe quotevalue prior9am between12and13 after13, absorb(effdate) vce(cluster Provname effmonth)
outreg2 using T9, stats(coef tstat)  excel dec(3) addtext(Day FE, Yes, Bank-Day FE, No)

reghdfe quotevalue prior9am between12and13 after13, absorb(bankday) vce(cluster Provname effmonth)
outreg2 using T9, stats(coef tstat)  excel dec(3) addtext(Day FE, No, Bank-Day FE, Yes)

***both together
reghdfe quotevalue prior9am between12and13 after13 ///
lagdailybanklossrate  ///
, absorb(bankday) vce(cluster Provname effmonth)
outreg2 using T9, stats(coef tstat)  excel dec(3) addtext(Day FE, No, Bank-Day FE, Yes)

reghdfe quotevalue prior9am between12and13 after13 ///
lagdailybanklossrate ///
c.prior9am#c.lagdailybanklossrate c.between12and13#c.lagdailybanklossrate c.after13#c.lagdailybanklossrate ///
, absorb(bankday) vce(cluster Provname effmonth)
outreg2 using T9, stats(coef tstat)  excel dec(3) addtext(Day FE, No, Bank-Day FE, Yes)












*************************************************************************************************************
***Table 10
cd "...path..."
use "Data 2005-2015,clean.dta", clear
cd "...path...\Stataoutput"
replace CDS=CDS/100
gen negquote=1 if quotevalue<0 & quotevalue!=.
replace negquote=0 if quotevalue>=0 & quotevalue!=.
gen timeinterval=1 if effquarter<=189 ///2005:Q1-2007:Q2

replace timeinterval=2 if effquarter>189 & effquarter<=199 ///2007:Q3-2009:Q4 financial crisis
replace timeinterval=3 if effquarter>199 & effquarter<=211 ///2010:Q1-2012:Q4 sovereign debt crisis
replace timeinterval=4 if effquarter>211  ///2013:Q1-2015:Q4


***Financial Crisis, Aug. 9, 2007 - Dec 31, 2009
gen fincrisis=1 if effdate>=17387 & effdate<=18262
replace fincrisis=0 if missing(fincrisis)
***Sovereign Debt Crisis
gen sovdebtcrisis=1 if effyear>=2010 & effyear<=2012
replace sovdebtcrisis=0 if missing(sovdebtcrisis)
***Crisis Aug. 9, 2007 - Dec, 31, 2012
gen crisis=1 if effdate>=17387 & effyear<=2012
replace crisis=0 if missing(crisis)
***pre-post Lehman
gen postLehman=1 if effdate>=17790 & effdate!=.
replace postLehman=0 if missing(postLehman)

***to get all periods in one variable:
gen periods=1 if effdate<17387
replace periods=2 if fincrisis==1
replace periods=3 if sovdebtcrisis==1
replace periods=4 if effyear>2012

***notional
gen helper=notionalamount if exec==1
by auction, sort: egen notional=total(helper)
gen lognotional=ln(notional)
gen logmaturity=ln(duration)

*divide countries into GIIPS, European non-GIIPS, and all others
gen COUNTRY=1 if country=="Austria" | country=="Belgium" | country=="Belgium/Netherlands" | country=="Denmark"| country=="France"| country=="Germany"| country=="Luxembourg"| country=="Netherlands"| country=="Scotland"| country=="Sweden"| country=="UK"
replace COUNTRY=2 if country=="Italien" | country=="Italy" | country=="Ireland" | country=="Spain"
replace COUNTRY=3 if missing(COUNTRY)

***to clean the Excel file again:
reg CDS
outreg2 using T10, stats(coef tstat) adjr2 excel dec(3) cttop(just to empty) replace

egen bankquarter=group(Provname effquarter)

gen quotevalueperc=quotevalue/100

egen Gruppeprice= group(auction quotevalue)


***3. two or more quotes are the same, as well as the relationship (interval) of the banks bidding, which one is more likely to be selected
gen Relamount=relamountbanklevel*100
***generate intervals for relationship to get "same" rel
gen Relamountinterval=1 if Relamount<10
replace Relamountinterval=2 if Relamount>=10 & Relamount<20
replace Relamountinterval=3 if Relamount>=20 & Relamount<30
replace Relamountinterval=4 if Relamount>=30 & Relamount<40
replace Relamountinterval=5 if Relamount>=40 & Relamount<50
replace Relamountinterval=6 if Relamount>=50 & Relamount<60
replace Relamountinterval=7 if Relamount>=60 & Relamount<70
replace Relamountinterval=8 if Relamount>=70 & Relamount<80
replace Relamountinterval=9 if Relamount>=80 & Relamount<90
replace Relamountinterval=10 if Relamount>=90 & Relamount!=.

egen Gruppepricerelamount= group(auction quotevalue Relamountinterval)

gen CDSgroup=1 if CDS<1
replace CDSgroup=2 if CDS>=1 & CDS<2
replace CDSgroup=3 if CDS>=2 & CDS<3
replace CDSgroup=4 if CDS>=3 & CDS!=.


*T10A.

reghdfe exec ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb(Gruppeprice) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote)

reghdfe exec ///
i.CDSgroup ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb(Gruppeprice) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote)


***************<=100mn threshold
reghdfe exec ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & notional<=100000000 , ///
absorb(Gruppeprice) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote)

reghdfe exec ///
i.CDSgroup ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & notional<=100000000 , ///
absorb(Gruppeprice) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote)


***************overnight
reghdfe exec ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & duration==1 , ///
absorb(Gruppeprice) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote)

reghdfe exec ///
i.CDSgroup ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & duration==1 , ///
absorb(Gruppeprice) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote)






**********************************conditional on relationship and price
***Price and Rel constant, same quote
reghdfe exec ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb(Gruppepricerelamount) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote, sameamtrel)


reghdfe exec ///
i.CDSgroup ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1, ///
absorb(Gruppepricerelamount) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote, sameamtrel)

***************<=100mn threshold
***Price and Rel constant, same quote
reghdfe exec ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & notional<=100000000 , ///
absorb(Gruppepricerelamount) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote, sameamtrel)


reghdfe exec ///
i.CDSgroup ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & notional<=100000000 , ///
absorb(Gruppepricerelamount) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote, sameamtrel)


***************overnight
***Price and Rel constant, same quote
reghdfe exec ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & duration==1 , ///
absorb(Gruppepricerelamount) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote, sameamtrel)


reghdfe exec ///
i.CDSgroup ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1  & duration==1, ///
absorb(Gruppepricerelamount) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote, sameamtrel)











*T10B.
***Two quotes are the same, both highest, which one is selected?

reghdfe exec ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & highestbid==1, ///
absorb(Gruppeprice) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote)

reghdfe exec ///
i.CDSgroup ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & highestbid==1, ///
absorb(Gruppeprice) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote)


***************<=100mn threshold
reghdfe exec ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & notional<=100000000  & highestbid==1, ///
absorb(Gruppeprice) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote)

reghdfe exec ///
i.CDSgroup ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & notional<=100000000  & highestbid==1, ///
absorb(Gruppeprice) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote)


***************overnight
reghdfe exec ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & duration==1  & highestbid==1, ///
absorb(Gruppeprice) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote)

reghdfe exec ///
i.CDSgroup ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & duration==1  & highestbid==1, ///
absorb(Gruppeprice) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote)






**********************************conditional on relationship and price
***Price and Rel constant, same quote
reghdfe exec ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & highestbid==1, ///
absorb(Gruppepricerelamount) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote, sameamtrel)


reghdfe exec ///
i.CDSgroup ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & highestbid==1, ///
absorb(Gruppepricerelamount) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote, sameamtrel)

***************<=100mn threshold
***Price and Rel constant, same quote
reghdfe exec ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & notional<=100000000  & highestbid==1, ///
absorb(Gruppepricerelamount) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote, sameamtrel)


reghdfe exec ///
i.CDSgroup ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & notional<=100000000  & highestbid==1, ///
absorb(Gruppepricerelamount) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote, sameamtrel)


***************overnight
***Price and Rel constant, same quote
reghdfe exec ///
CDS ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1 & duration==1  & highestbid==1, ///
absorb(Gruppepricerelamount) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote, sameamtrel)


reghdfe exec ///
i.CDSgroup ///
firstbid ///
logtotassets leverage npl_grossloans ROE assetgrowth interestmargin OBSitems_assets ///
if numberquotes>1 & exec_trans==1  & duration==1 & highestbid==1, ///
absorb(Gruppepricerelamount) vce(cluster Provname effmonth)
outreg2 using T10, stats(coef tstat) excel dec(3) cttop(T3, samequote, sameamtrel)



